// Example STEP-NC Program using COM
// ========================================
//
// This sample C++ project calls the STEP-NC Machine Programming API
// using the COM interface.  The program creates a small machining
// program with a few toolpath moves.  
//
// The project creates a command line program that writes test.stpnc.
// You can find more examples and other programming documentation at:
//
//    http://www.steptools.com/support/stepnc_docs/
//

#include <comutil.h>
#include <stdio.h>

#import <mscorlib.tlb>
#import <System.tlb>

// The namespace and TBL files are different depending on whether you
// are using the 32bit or 64bit version of the library.  The calls are
// otherwise the same.
#ifdef _WIN64
#import "c:\\Program Files (x86)\\STEP Tools\\STEP-NC Machine\\stepnc_x64.tlb" 
#define STEPNC_NAMESPACE stepnc_x64
using namespace stepnc_x64;
#else
#import "c:\\Program Files (x86)\\STEP Tools\\STEP-NC Machine\\stepnc_x86.tlb" 
#define STEPNC_NAMESPACE stepnc_x86
using namespace stepnc_x86;
#endif

using namespace std;

// This example uses the COM Smart pointers, which have an underscore
// prefix and "Ptr" suffix.  You can also do it the old-school way
// using CoCreateInstance
_AptStepMakerPtr oApt;


int main(int argc, char* argv[])
{
    // Initialize COM.
    HRESULT hr = CoInitialize(NULL);

    if (!SUCCEEDED (hr)) {
	printf("Could not initialize COM\n"); 
	return 1;
    }

    // This how smart pointers create the instance
    hr = oApt.CreateInstance(__uuidof(AptStepMaker));
    if (!SUCCEEDED (hr)) {
	printf("Could not initialize Apt instance\n"); 
	return 1;
    }

    // Create a trivial STEP-NC file
    oApt->PartNo ("test part");
    oApt->DefineTool (0.25, 5.0, 1.0, 2.0, 3.0, 4.0, 5.0);
    oApt->LoadTool (1);
    oApt->Rapid ();
    oApt->GoToXYZ ("point001", 1.0, 12.0, 0.0);          
    oApt->GoToXYZ ("point002", 1.0, 14.0, 0.0);
    oApt->SaveAsModules ("test");

    // Clean up when finished with COM
    CoUninitialize();
    return 0;
}
